<?php
/**
 * SMH functions and definitions
 */


/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function smh_setup() {

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top'    => __( 'Top Menu', 'smh' ),
		'mobile-head-bottom' => __( 'Header bottom mobile menu', 'smh' ),
		'footer-1'    => __( 'Footer 2 columns Menu', 'smh' ),
		'footer-2'    => __( 'Footer 1 column Menu', 'smh' ),
		'footer-3'    => __( 'Footer Bottom Menu', 'smh' ),
	) );
	// ACF options page
	if( function_exists('acf_add_options_page') ) {
		acf_add_options_page();
	}	



}
add_action( 'after_setup_theme', 'smh_setup' );

function fix_svg_thumb_display() {
  echo '<style>
    li.attachment img[src$=".svg"], img[src$=".svg"].attachment-post-thumbnail { 
      width: 100% !important; 
      height: auto !important; 
    }
  </style>';
}
add_action('admin_head', 'fix_svg_thumb_display');

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 */
function smh_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'twentyseventeen' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'smh_excerpt_more' );

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 */
function smh_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'smh_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 */
function smh_scripts() {
	// Add custom styles.  
	wp_enqueue_style( 'smh-bootstrap', get_theme_file_uri( '/assets/css/bootstrap.css' ), array(), null );
	wp_enqueue_style( 'smh-font-awesome', get_theme_file_uri( '/assets/font-awesome/css/font-awesome.css' ), array(), null );
	wp_enqueue_style( 'smh-styles', get_theme_file_uri( '/assets/css/styles.css' ), array(), null );
	wp_enqueue_style( 'smh-responsive', get_theme_file_uri( '/assets/css/responsive.css' ), array(), null );
	// Theme stylesheet.
	wp_enqueue_style( 'smh-style', get_stylesheet_uri() );

	wp_enqueue_script( 'smh-bootstrap-js', get_theme_file_uri( '/assets/js/bootstrap.min.js' ), array('jquery'), '1.0', true );
	wp_enqueue_script( 'smh-custom-js', get_theme_file_uri( '/assets/js/custom.js' ), array('jquery'), '1.0', true );
	wp_enqueue_script( 'smh-function-js', get_theme_file_uri( '/assets/js/functions.js' ), array('jquery'), '1.0', true );	
}
add_action( 'wp_enqueue_scripts', 'smh_scripts' );
// Add copyrigth to Mobile Header Bottom menu
add_filter( 'wp_nav_menu_items', 'your_custom_menu_item', 10, 2 );
function your_custom_menu_item ( $items, $args ) {
    if (($args->theme_location == 'mobile-head-bottom') && (get_field('smh_copyright','options'))) {
    	$items .= '<li>'.get_field('smh_copyright','options').'</li>';
    }
    return $items;
}
//Add "parent" class to pages with subpages, change submenu class name, add depth class

    class Prio_Walker extends Walker_Nav_Menu {
    function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ){
        $GLOBALS['dd_children'] = ( isset($children_elements[$element->ID]) )? 1:0;
        $GLOBALS['dd_depth'] = (int) $depth;
        parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    }

     function start_lvl(&$output, $depth) {
    $indent = str_repeat("\t", $depth);
    $output .= "\n$indent<ul class=\"custom-navigation-sub sub-menu\">\n";
  }
}

add_filter('nav_menu_css_class','add_parent_css',10,2);
function  add_parent_css($classes, $item){
     global  $dd_depth, $dd_children;
     $classes[] = 'depth'.$dd_depth;
     if($dd_children)
         $classes[] = 'sub-menu-parent';
    return $classes;
}

//Add class to parent pages to show they have subpages (only for automatic wp_nav_menu)

function add_parent_class( $css_class, $page, $depth, $args )
{
   if ( ! empty( $args['has_children'] ) )
       $css_class[] = 'sub-menu-parent';
   return $css_class;
}
add_filter( 'page_css_class', 'add_parent_class', 10, 4 );
add_filter('wp_nav_menu_items','add_custom_in_menu', 10, 2);

function add_custom_in_menu( $items, $args ) 
{
    if( $args->theme_location == 'footer-1' ) // only for primary menu
    {
        $items_array = array();
        while ( false !== ( $item_pos = strpos ( $items, '<li', 3 ) ) )
        {
            $items_array[] = substr($items, 0, $item_pos);
            $items = substr($items, $item_pos);
        }
        $items_array[] = $items;
        $numiten = ceil(count($items_array)/2);
        array_splice($items_array, $numiten, 0, '</ul></div><div class="list-container"><ul class="menu">'); // insert custom item after 2nd one

        $items = implode('', $items_array);
    }
    return $items;
}